%if femdk:
CMAKE_MINIMUM_REQUIRED( VERSION 2.6 )

PROJECT( FEMDK_${basename.upper()} )

# Set path for CMake dependencies
IF(NOT DEFINED CMAKE_MODULE_PATH)
  # This block is executed only if this project is configuread as stand alone
  # that is not as a subproject of 'femdk' project
  SET(CMAKE_MODULE_PATH 
      "${'$'}{CMAKE_SOURCE_DIR}/config/cmake_modules/" 
      ${femdkinstalldir}/share/femdk/cmake_modules
      CACHE PATH "Path to FEMDK configuration directory")
ENDIF(NOT DEFINED CMAKE_MODULE_PATH)

INCLUDE(SetBaseDir)
INCLUDE(SetHostSpecific)
INCLUDE(UtilsFEMDK)

# Uncomment and specify package name used by program if any
FIND_PACKAGE(AutoOpts)
FIND_PACKAGE(CppUnit)
FIND_PACKAGE(Log4Cpp)
FIND_PACKAGE(Boost COMPONENTS system filesystem REQUIRED)
FIND_PACKAGE(BoostProcess REQUIRED)
FIND_PACKAGE(FEMDK REQUIRED)

# Add any specific directores required by a program to compile
INCLUDE_DIRECTORIES( 
     ${'$'}{CMAKE_SOURCE_DIR}
     ${'$'}{PROJECT_SOURCE_DIR}
     ${'$'}{PROJECT_BINARY_DIR}
     ${'$'}{AUTOOPTS_INCLUDE_DIRS}
     ${'$'}{LOG4CPP_INCLUDE_DIRS}
     ${'$'}{CPPUNIT_INCLUDE_DIRS}
     ${'$'}{BOOSTPROCESS_INCLUDE_DIRS}
     ${'$'}{BOOST_INCLUDE_DIRS}
     ${'$'}{FEMDK_INCLUDE_DIRS}
)

ADD_DEFINITIONS(${'$'}{AUTOOPTS_CFLAGS}
                ${'$'}{LOG4CPP_FLAGS}
               )

LINK_DIRECTORIES(${'$'}{CMAKE_SOURCE_DIR}
                )

GENERATE_CONF_HEADER(${basename})
GENERATE_OPTSOURCE(${basename} output logger misc)
ADD_EXECUTABLE(${basename} ${basename}.cxx ${basename}_options.c ${basename}_options.h)
TARGET_LINK_LIBRARIES(${basename} ${'$'}{AUTOOPTS_LIBRARIES}
                                  ${'$'}{FEMDK_LIBRARY}
                                  ${'$'}{Boost_LIBRARIES}
                      )

#SET_TARGET_PROPERTIES(${basename}
#                      PROPERTIES EXCLUDE_FROM_ALL TRUE)

# INSTALL( PROGRAMS ${'$'}{CMAKE_CURRENT_BINARY_DIR}/${basename} DESTINATION bin )
%else:
CMAKE_MINIMUM_REQUIRED( VERSION 2.6 )

PROJECT( ${basename.upper()} )

# Executable name:
SET(EXEC_NAME ${basename})

# The version number.
set (${'$'}{EXEC_NAME}_VERSION_MAJOR 0)
set (${'$'}{EXEC_NAME}_VERSION_MINOR 1)


# Directory where program dependencies are located
SET( BASE_DIR "/space/install" CACHE PATH 
                            "Top istall dir for program dependencies")

SET(CMAKE_MODULE_PATH "${'$'}{CMAKE_SOURCE_DIR}/config/cmake_modules/")

# configure a header file to pass some of the CMake settings
# to the source code
CONFIGURE_FILE (
  "${'$'}{PROJECT_SOURCE_DIR}/${'$'}{EXEC_NAME}_config.h.in"
  "${'$'}{PROJECT_BINARY_DIR}/${'$'}{EXEC_NAME}_config.h"
)

# Uncomment and specify package name used by program if any
FIND_PACKAGE(AutoOpts)

# Add any specific directores required by a program to compile
INCLUDE_DIRECTORIES( ${'$'}{PROJECT_BINARY_DIR})
% if cmdlgener == 'autoopt':
INCLUDE_DIRECTORIES( ${'$'}{AUTOOPTS_INCLUDE_DIRS} ) 
%endif 

% if cmdlgener == 'autoopt':
ADD_DEFINITIONS(${'$'}{AUTOOPTS_CFLAGS})

LINK_DIRECTORIES( ${'$'}{BASE_DIR}/lib ${'$'}{AUTOOPTS_LIBRARY_DIRS} )

SET( CMDL_SRC ${'$'}{EXEC_NAME}_options.h ${'$'}{EXEC_NAME}_options.c)

GENERATE_OPTSOURCE(${'$'}{EXEC_NAME})
%endif 

SET( SRCS ${'$'}{EXEC_NAME}.cxx ${'$'}{CMDL_SRC})

ADD_EXECUTABLE( ${'$'}{EXEC_NAME} ${'$'}{SRCS} )

%if cmdlgener == 'autoopt':
TARGET_LINK_LIBRARIES(${'$'}{EXEC_NAME} ${'$'}{AUTOOPTS_LIBRARIES} )
% endif

#SET_TARGET_PROPERTIES(${'$'}{EXEC_NAME}
#                      PROPERTIES EXCLUDE_FROM_ALL TRUE)

%endif
# INSTALL( PROGRAMS ${'$'}{CMAKE_CURRENT_BINARY_DIR}/(${'$'}{EXEC_NAME} DESTINATION bin )
