/*
% if femdk:
 * This file is a part of FEMDK, a Finite Element Method Development Kit.
 * FEMDK provides utilities of developing simulation codes base on various 
 * variants of finite element method.
 *
 * Project web page: https://femdk.l5.pk.edu.pl/femdk
% endif
 * 
 * Copyright (c) ${year} ${owner} 
 * 
% if license == 'BSD':
 * This file is distributed on "Simplified BSD License" as approved by 
 * the OSI Board. For licensing terms see LICENSE.BSD file distributed 
 * with this file.
% endif
 */

/*
 * Author: ${author} <${email}>
 * Created: ${date}
 * Modified by:
 */
/** 
 *  This file defines beafire exceptions and exception handling related
 *  utilities.
 */

${'#'}ifndef ${header_guard} 
${'#'}define ${header_guard}

#include <exception>
#include <QString>

class DataValue;

class ${qtcp}Exception : public std::exception {
  public:
    ${qtcp}Exception() : message("Unknown ${basename.upper()} exception") {}
    explicit ${qtcp}Exception(const char *msg): message(msg) {}
    explicit ${qtcp}Exception(const QString &msg) : message(msg) {}
    virtual ~${qtcp}Exception() throw () {}
    virtual const char* what() const throw() {
       return message.toStdString().c_str(); 
    }
  protected:
    QString message;
};

/** Exception class thrown in case of internal errors -- e.g. 
    inside algorithm branches that should be not executed in given 
    context. 
 */
class ${qtcp}InternalError : public ${qtcp}Exception  {
  public:
    explicit ${qtcp}InternalError(const char *msg) : ${qtcp}Exception(msg) {}
    explicit ${qtcp}InternalError(const QString &msg) : ${qtcp}Exception(msg) {}
    virtual ~${qtcp}InternalError() throw () {}
};

class ${qtcp}NotImplemented : public ${qtcp}Exception  {
  public:
    explicit ${qtcp}NotImplemented(QString &fname) : ${qtcp}Exception(QString("Not implemented: %1").arg(fname)) {}
    explicit ${qtcp}NotImplemented(const char *fname) : ${qtcp}Exception(QString("Not implemented: %1").arg(fname)) {}
    explicit ${qtcp}NotImplemented() : ${qtcp}Exception(QString("Feature not implemented")) {}
    virtual ~${qtcp}NotImplemented() throw () {}
};

class ${qtcp}ValueNotSet : public ${qtcp}Exception  {
  public:
    explicit ${qtcp}ValueNotSet(DataValue *v);
    virtual ~${qtcp}ValueNotSet() throw () {}
    virtual const char* what() const throw() {
       return message.toStdString().c_str(); 
    }
};

#endif /* ${header_guard} */
