#!/usr/bin/env python
# -*- coding: ISO-8859-1 -*-

"""Generate source and header file skeletons for C++ modules or programs
"""

import distutils.sysconfig
import distutils.fancy_getopt
from distutils.command.install import install
from distutils.command.build_scripts import build_scripts
from distutils.command.install_scripts import install_scripts
from distutils.core import setup
import sys
import os

#=============================================================================
# USER CONFIGURABLE OPTIONS
#===========================================================================


#============================================================================
# AUXILIARY CLASSES AND FUNCTIONS FOR SETUP
#============================================================================ 
class augmented_install(install):
    def __init__(self, dist):
        install.__init__(self,dist)
    def run(self):
        global DATAPATH
        global VERSION
        name = self.config_vars['dist_name']
        DATAPATH = os.path.join(self.install_data, "share", name);
        VERSION = self.config_vars['dist_version']
        install.run(self) 
         

class augmented_install_scripts(install_scripts):
    def __init__(self, dist):
        install_scripts.__init__(self,dist)
    def run(self):
        global DATAPATH
        global VERSION
        print dir(self)
        install_scripts.run(self) 
        print "Fixind template path to ", DATAPATH 
        for f in  self.get_outputs():
            file = open(f, "r")
            contents = file.read().replace("%TEMPLATEDIR%", DATAPATH)
            contents = contents.replace("%VERSION%", VERSION)
            file.close()
            file = open(f,"w")
            file.write(contents)
            file.close

class augmented_build_scripts(build_scripts):
    def __init__(self, dist):
        build_scripts.__init__(self,dist)
    def run(self):
        build_scripts.run(self) 

#============================================================================
# EXTENSION MODULES SPECIFICATION
#============================================================================ 

#============================================================================= 
#  NEW SETUP COMMANDS
#=============================================================================


#=============================================================================
if sys.version_info >= (2, 3):
    addargs = { "classifiers":
                [ "Development Status :: 3 - Alpha",
                  "Intended Audience :: Developers",
                  "License :: OSI Approved :: BSD License",
                  "Operating System :: OS Independent",
                  "Programming Language :: Python",
                  "Topic :: Software Development :: Code Generators"
                ],
                "download_url":
                    "https://www.L5.pk.edu.pl/~putanowr/mkcxxmodule.html",
                "platforms":
                    "OS independent",
              }
else:
    addargs = {}

# We're using the module docstring as the distutils descriptions. 
# (seen in Zope3 setup.py)
doclines = __doc__.split("\n")

setup(name              = "mkcxxmodule",
      version           = "0.5.0",
      author            = "Roman Putanowicz",
      author_email      = "R.Putanowicz at L5.pk.edu.pl",
      url               = "https://www.L5.pk.edu.pl/~putanowr/mkcxxmodule.html",
      description       = doclines[0],
      long_description  = "\n".join(doclines[2:]),
      license           = "BSD Licence",
      scripts           = ['mkcxxmodule.py'],
      data_files       = [('share/mkcxxmodule',
                           ['mkcxx_header.mako',
                            'mkcxx_source.mako', 
                            'mkcxx_test_source.mako',
                            'mkcxx_program_conf.mako',
                            'mkcxx_bootstrap.mako',
                            'mkcxx_cleanALL.mako',
                            'mkcxx_program_optdef.mako',
                            'mkcxx_program_cmake.mako', 
                            'mkcxx_program_source.mako',
                            'mkcxx_qt_except_h.mako'])],
      cmdclass = {'install' : augmented_install, 
                  'build_scripts' : augmented_build_scripts,
                  'install_scripts' : augmented_install_scripts},
      **addargs)
